@@ -598,6 +598,33 @@ NV_STATUS NV_API_CALL nv_dma_unmap_alloc
     return NV_OK;
 }
 
+static NvBool nv_dma_is_map_resource_implemented
+(
+    nv_linux_state_t *nvl
+)
+{
+#if defined(NV_DMA_MAP_RESOURCE_PRESENT)
+    const struct dma_map_ops *ops = get_dma_ops(&nvl->dev->dev);
+
+    if (ops == NULL)
+    {
+        /* On pre-5.0 kernels, if dma_map_resource() is present, then we
+         * assume that ops != NULL.  With direct_dma handling swiotlb on 5.0+
+         * kernels, ops == NULL.
+         */
+#if defined(NV_DMA_IS_DIRECT_PRESENT)
+        return NV_TRUE;
+#else
+        return NV_FALSE;
+#endif
+    }
+
+    return (ops->map_resource != NULL);
+#else
+    return NV_FALSE;
+#endif
+}
+
 /* DMA-map a peer PCI device's BAR for peer access. */
 NV_STATUS NV_API_CALL nv_dma_map_peer
 (
@@ -672,15 +699,14 @@ NV_STATUS NV_API_CALL nv_dma_map_mmio
 #if defined(NV_DMA_MAP_RESOURCE_PRESENT)
     NvU64 mmio_addr;
     nv_linux_state_t *nvl = NV_GET_NVL_FROM_NV_STATE(nv);
-    const struct dma_map_ops *ops = get_dma_ops(&nvl->dev->dev);
 
-    /* 
+    /*
      * The default implementation passes through the source address
      * without failing. However, we may want to try something else
      * so we need to be able to differentiate between no map_resource
      * implementation and no change to the mapped address.
      */
-    if (!ops->map_resource)
+    if (!nv_dma_is_map_resource_implemented(nvl))
     {
         return NV_ERR_NOT_SUPPORTED;
     }
@@ -716,10 +742,9 @@ void NV_API_CALL nv_dma_unmap_mmio
 {
 #if defined(NV_DMA_MAP_RESOURCE_PRESENT)
     nv_linux_state_t *nvl = NV_GET_NVL_FROM_NV_STATE(nv);
-    const struct dma_map_ops *ops = get_dma_ops(&nvl->dev->dev);
 
     /* Make sure we only unmap what we mapped */
-    if (!ops->map_resource)
+    if (!nv_dma_is_map_resource_implemented(nvl))
     {
         return;
     }
